@@ -11,7 +11,8 @@ expect_optim_works <- function(optim, defaults) {
   }
   
   w <- torch_randn(10, 1, requires_grad = TRUE)
-  defaults[["params"]] <- list(w)
+  z <- torch_randn(10, 1, requires_grad = TRUE)
+  defaults[["params"]] <- list(w, z)
   opt <- do.call(optim, defaults)
   
   fn <- function() {
